GliaML
------

GliaML is simple, yet powerful machine learning library written in Python.

Currently, it allows a user to easily create a multi-layer perceptron neural network with
the following features:

    1. Allow backpropagation with the sigmoid, tanh, and ReLU activation functions.
    2. Allow normalisation of a classifier with the softmax function.
    3. Allow learning rate hyperparameter functionality (including biases)

See example.py for usage.